pub struct AudioTranslationParameters {
pub file: FileUpload,
pub model: String,
pub prompt: Option<String>,
pub response_format: Option<AudioOutputFormat>,
pub temperature: Option<f32>,
}Fields
file: FileUploadThe audio file object to translate, in one of these formats: flac, mp3, mp4, mpeg, mpga, m4a, ogg, wav, or webm.
model: StringID of the model to use. Only whisper-1 is currently available.
prompt: Option<String>An optional text to guide the model’s style or continue a previous audio segment. The prompt should be in English.
response_format: Option<AudioOutputFormat>The format of the transcript output, in one of these options: json, text, srt, verbose_json, or vtt.
temperature: Option<f32>The sampling temperature, between 0 and 1. Higher values like 0.8 will make the output more random, while lower values like 0.2 will make it more focused and deterministic. If set to 0, the model will use log probability to automatically increase the temperature until certain thresholds are hit.