pub struct AudioTranslationParametersBuilder { /* private fields */ }Expand description
Builder for AudioTranslationParameters.
Implementations
Sourceimpl AudioTranslationParametersBuilder
impl AudioTranslationParametersBuilder
Sourcepub fn file<VALUE: Into<FileUpload>>(&mut self, value: VALUE) -> &mut Self
pub fn file<VALUE: Into<FileUpload>>(&mut self, value: VALUE) -> &mut Self
The audio file object to translate, in one of these formats: flac, mp3, mp4, mpeg, mpga, m4a, ogg, wav, or webm.
Sourcepub fn model<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
pub fn model<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
ID of the model to use. Only whisper-1 is currently available.
Sourcepub fn prompt<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
pub fn prompt<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
An optional text to guide the model’s style or continue a previous audio segment. The prompt should be in English.
Sourcepub fn response_format<VALUE: Into<AudioOutputFormat>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn response_format<VALUE: Into<AudioOutputFormat>>( &mut self, value: VALUE, ) -> &mut Self
The format of the transcript output, in one of these options: json, text, srt, verbose_json, or vtt.
Sourcepub fn temperature<VALUE: Into<f32>>(&mut self, value: VALUE) -> &mut Self
pub fn temperature<VALUE: Into<f32>>(&mut self, value: VALUE) -> &mut Self
The sampling temperature, between 0 and 1. Higher values like 0.8 will make the output more random, while lower values like 0.2 will make it more focused and deterministic. If set to 0, the model will use log probability to automatically increase the temperature until certain thresholds are hit.
Sourcepub fn build(
&self,
) -> Result<AudioTranslationParameters, AudioTranslationParametersBuilderError>
pub fn build( &self, ) -> Result<AudioTranslationParameters, AudioTranslationParametersBuilderError>