pub enum ChatMessage {
Developer {
content: ChatMessageContent,
name: Option<String>,
},
System {
content: ChatMessageContent,
name: Option<String>,
},
User {
content: ChatMessageContent,
name: Option<String>,
},
Assistant {
content: Option<ChatMessageContent>,
reasoning_content: Option<String>,
refusal: Option<String>,
name: Option<String>,
audio: Option<AudioDataIdParameter>,
tool_calls: Option<Vec<ToolCall>>,
},
Tool {
content: ChatMessageContent,
tool_call_id: String,
},
}Variants
Developer
Fields

content: ChatMessageContentThe contents of the developer message.
System
Fields

content: ChatMessageContentThe contents of the system message.
User
Fields

content: ChatMessageContentThe contents of the user message.
Assistant
Fields

content: Option<ChatMessageContent>The contents of the assistant message. Required unless tool_calls is specified.

name: Option<String>An optional name for the participant. Provides the model information to differentiate between participants of the same role.

audio: Option<AudioDataIdParameter>Data about a previous audio response from the model.
Tool
Fields

content: ChatMessageContentThe contents of the tool message.
Implementations