ChatCompletionParameters

Struct ChatCompletionParameters 

pub struct ChatCompletionParameters {
Show 31 fields pub messages: Vec<ChatMessage>, pub model: String, pub store: Option<bool>, pub reasoning_effort: Option<ReasoningEffort>, pub metadata: Option<HashMap<String, String>>, pub frequency_penalty: Option<f32>, pub logit_bias: Option<HashMap<String, i32>>, pub logprobs: Option<bool>, pub top_logprobs: Option<u32>, pub max_tokens: Option<u32>, pub max_completion_tokens: Option<u32>, pub n: Option<u32>, pub modalities: Option<Vec<Modality>>, pub prediction: Option<PredictedOutput>, pub audio: Option<AudioParameters>, pub presence_penalty: Option<f32>, pub response_format: Option<ChatCompletionResponseFormat>, pub seed: Option<u32>, pub stop: Option<StopToken>, pub stream: Option<bool>, pub stream_options: Option<ChatCompletionStreamOptions>, pub temperature: Option<f32>, pub top_p: Option<f32>, pub tools: Option<Vec<ChatCompletionTool>>, pub tool_choice: Option<ChatCompletionToolChoice>, pub parallel_tool_calls: Option<bool>, pub safety_identifier: Option<String>, pub prompt_cache_key: Option<String>, pub web_search_options: Option<WebSearchOptions>, pub extra_body: Option<Value>, pub query_params: Option<HashMap<String, String>>,
}

Fields

messages: Vec<ChatMessage>

A list of messages comprising the conversation so far.

model: String

ID of the model to use.

store: Option<bool>

Whether or not to store the output of this chat completion request for use in our model distillation or evals products.

reasoning_effort: Option<ReasoningEffort>

Constrains effort on reasoning for reasoning models.

metadata: Option<HashMap<String, String>>

Developer-defined tags and values used for filtering completions in the dashboard.

frequency_penalty: Option<f32>

Number between -2.0 and 2.0. Positive values penalize new tokens based on their existing frequency in the text so far, decreasing the model’s likelihood to repeat the same line verbatim.

logit_bias: Option<HashMap<String, i32>>

Modify the likelihood of specified tokens appearing in the completion.

logprobs: Option<bool>

Whether to return log probabilities of the output tokens or not. If true, returns the log probabilities of each output token returned in the ‘content’ of ‘message’.

top_logprobs: Option<u32>

An integer between 0 and 5 specifying the number of most likely tokens to return at each token position, each with an associated log probability. ‘logprobs’ must be set to ‘true’ if this parameter is used.

max_tokens: Option<u32>

Max completion tokens, deprecated (still used by vllm)

max_completion_tokens: Option<u32>

An upper bound for the number of tokens that can be generated for a completion, including visible output tokens and reasoning tokens.

n: Option<u32>

How many chat completion choices to generate for each input message.

modalities: Option<Vec<Modality>>

Output types that you would like the model to generate for this request.

prediction: Option<PredictedOutput>

Configuration for a Predicted Output, which can greatly improve response times when large parts of the model response are known ahead of time. This is most common when you are regenerating a file with only minor changes to most of the content.

audio: Option<AudioParameters>

Parameters for audio output. Required when audio output is requested with modalities: [“audio”].

presence_penalty: Option<f32>

Number between -2.0 and 2.0. Positive values penalize new tokens based on whether they appear in the text so far, increasing the model’s likelihood to talk about new topics.

response_format: Option<ChatCompletionResponseFormat>

An object specifying the format that the model must output. Compatible with GPT-4o, GPT-4o mini, GPT-4 Turbo and all GPT-3.5 Turbo models newer than gpt-3.5-turbo-1106. Setting to { “type”: “json_schema”, “json_schema”: {…} } enables Structured Outputs which ensures the model will match your supplied JSON schema. Setting to { “type”: “json_object” } enables JSON mode, which ensures the message the model generates is valid JSON.

seed: Option<u32>

Deprecated (still used by vllm) This feature is in Beta. If specified, our system will make a best effort to sample deterministically, such that repeated requests with the same seed and parameters should return the same result. Determinism is not guaranteed, and you should refer to the system_fingerprint response parameter to monitor changes in the backend.

stop: Option<StopToken>

Up to 4 sequences where the API will stop generating further tokens.

stream: Option<bool>

If set, partial messages will be sent, like in ChatGPT. Tokens will be sent as data-only server-sent events as they become available, with the stream terminated by a data: [DONE] message.

stream_options: Option<ChatCompletionStreamOptions>

Options for streaming response. Only set this when you set stream: true.

temperature: Option<f32>

What sampling temperature to use, between 0 and 2. Higher values like 0.8 will make the output more random, while lower values like 0.2 will make it more focused and deterministic.

top_p: Option<f32>

An alternative to sampling with temperature, called nucleus sampling, where the model considers the results of the tokens with top_p probability mass. So 0.1 means only the tokens comprising the top 10% probability mass are considered.

tools: Option<Vec<ChatCompletionTool>>

A list of tools the model may call. Currently, only functions are supported as a tool. Use this to provide a list of functions the model may generate JSON inputs for.

tool_choice: Option<ChatCompletionToolChoice>

Controls which (if any) tool is called by the model. none means the model will not call any tool and instead generates a message. auto means the model can pick between generating a message or calling one or more tools. required means the model must call one or more tools. Specifying a particular tool via {“type”: “function”, “function”: {“name”: “my_function”}} forces the model to call that tool.

parallel_tool_calls: Option<bool>

Whether to enable parallel function calling during tool use.

safety_identifier: Option<String>

A stable identifier used to help detect users of your application that may be violating OpenAI’s usage policies.

prompt_cache_key: Option<String>

Used by OpenAI to cache responses for similar requests to optimize your cache hit rates.

web_search_options: Option<WebSearchOptions>

This tool searches the web for relevant results to use in a response.

extra_body: Option<Value>

Allows to pass arbitrary json as an extra_body parameter, for specific features/openai-compatible endpoints.

query_params: Option<HashMap<String, String>>

Azure OpenAI and some other providers may require special query parameters to be set on the request URL. This field allows you to specify those query parameters.