pub struct LogProbsContentInfo {
pub token: String,
pub logprob: f32,
pub bytes: Option<Vec<u8>>,
}Fields
token: StringThe token.
logprob: f32The log probability of this token, if it is within the top 20 most likely tokens. Otherwise, the value -9999.0 is used to signify that the token is very unlikely.
bytes: Option<Vec<u8>>A list of integers representing the UTF-8 bytes representation of the token.