pub struct LogProps {
pub content: Option<Vec<LogPropsContent>>,
pub refusal: Option<Vec<LogPropsContent>>,
}Fields
content: Option<Vec<LogPropsContent>>A list of message content tokens with log probability information.
refusal: Option<Vec<LogPropsContent>>A list of message refusal tokens with log probability information.