pub struct PredictedOutput {
pub type: PredictedOutputType,
pub content: PredictedOutputContent,
}Fields
type: PredictedOutputTypeThe type of the predicted content you want to provide.
content: PredictedOutputContentThe content that should be matched when generating a model response. If generated tokens would match this content, the entire model response can be returned much more quickly.