pub struct Embedding {
pub index: u32,
pub embedding: EmbeddingOutput,
pub object: String,
}Fields
index: u32The index of the embedding in the list of embeddings.
embedding: EmbeddingOutputThe embedding vector, which is a list of floats. Or String when encoding format is set to ‘base64’.
object: StringThe object type, which is always “embedding”.