pub struct EmbeddingParameters {
pub input: EmbeddingInput,
pub model: String,
pub encoding_format: Option<EmbeddingEncodingFormat>,
pub dimensions: Option<u32>,
pub user: Option<String>,
}Fields
input: EmbeddingInputInput text to embed, encoded as a string or array of tokens. To embed multiple inputs in a single request, pass an array of strings or array of token arrays.
model: StringID of the model to use.
encoding_format: Option<EmbeddingEncodingFormat>The format to return the embeddings in. Can be either float or base64.
dimensions: Option<u32>The number of dimensions the resulting output embeddings should have. Only supported in ‘text-embedding-3’ and later models.
user: Option<String>A unique identifier representing your end-user, which can help OpenAI to monitor and detect abuse.