pub struct EmbeddingParametersBuilder { /* private fields */ }Expand description
Builder for EmbeddingParameters.
Implementations
Sourceimpl EmbeddingParametersBuilder
impl EmbeddingParametersBuilder
Sourcepub fn input<VALUE: Into<EmbeddingInput>>(&mut self, value: VALUE) -> &mut Self
pub fn input<VALUE: Into<EmbeddingInput>>(&mut self, value: VALUE) -> &mut Self
Input text to embed, encoded as a string or array of tokens. To embed multiple inputs in a single request, pass an array of strings or array of token arrays.
Sourcepub fn model<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
pub fn model<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
ID of the model to use.
Sourcepub fn encoding_format<VALUE: Into<EmbeddingEncodingFormat>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn encoding_format<VALUE: Into<EmbeddingEncodingFormat>>( &mut self, value: VALUE, ) -> &mut Self
The format to return the embeddings in. Can be either float or base64.
Sourcepub fn dimensions<VALUE: Into<u32>>(&mut self, value: VALUE) -> &mut Self
pub fn dimensions<VALUE: Into<u32>>(&mut self, value: VALUE) -> &mut Self
The number of dimensions the resulting output embeddings should have. Only supported in ‘text-embedding-3’ and later models.
Sourcepub fn user<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
pub fn user<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
A unique identifier representing your end-user, which can help OpenAI to monitor and detect abuse.
Sourcepub fn build(
&self,
) -> Result<EmbeddingParameters, EmbeddingParametersBuilderError>
pub fn build( &self, ) -> Result<EmbeddingParameters, EmbeddingParametersBuilderError>