pub struct Headers {
pub x_ratelimit_limit_requests: Option<u32>,
pub x_ratelimit_limit_tokens: Option<u32>,
pub x_ratelimit_remaining_requests: Option<u32>,
pub x_ratelimit_remaining_tokens: Option<u32>,
pub x_ratelimit_reset_requests: Option<String>,
pub x_ratelimit_reset_tokens: Option<String>,
}Fields
x_ratelimit_limit_requests: Option<u32>The maximum number of requests that are permitted before exhausting the rate limit.
x_ratelimit_limit_tokens: Option<u32>The maximum number of tokens that are permitted before exhausting the rate limit.
x_ratelimit_remaining_requests: Option<u32>The remaining number of requests that are permitted before exhausting the rate limit.
x_ratelimit_remaining_tokens: Option<u32>The remaining number of tokens that are permitted before exhausting the rate limit.
x_ratelimit_reset_requests: Option<String>The time until the rate limit (based on requests) resets to its initial state.
x_ratelimit_reset_tokens: Option<String>The time until the rate limit (based on tokens) resets to its initial state.