pub struct ListParameters {
pub limit: Option<u32>,
pub order: Option<String>,
pub after: Option<String>,
pub before: Option<String>,
}Fields
limit: Option<u32>A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 20.
order: Option<String>Sort order by the created_at timestamp of the objects. asc for ascending order and desc for descending order.
after: Option<String>A cursor for use in pagination. after is an object ID that defines your place in the list.
before: Option<String>A cursor for use in pagination. before is an object ID that defines your place in the list.